<?php
/**
 * Listeners
 *
 * @package GamiPress\PeepSo\Listeners
 * @since 1.0.0
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Common user events listener
 *
 * @since 1.0.0
 *
 * @param int $user_id  The user ID
 */
function gamipress_peepso_common_user_listener( $user_id ) {

    // Trigger events depending of current filter since is a common listener
    switch( current_filter() ) {
        case 'peepso_user_after_change_avatar':
            do_action( 'gamipress_peepso_change_avatar', $user_id );
            break;
        case 'peepso_user_after_change_cover':
            do_action( 'gamipress_peepso_change_cover', $user_id );
            break;
    }

}
do_action( 'peepso_user_after_change_avatar', 'gamipress_peepso_common_user_listener', 10 );
do_action( 'peepso_user_after_change_cover', 'gamipress_peepso_common_user_listener', 10 );

/**
 * Common new activities events listener
 *
 * @since 1.0.0
 *
 * @param int $post_id      Post ID attached to the activity (PeepSo activity comments are post too)
 * @param int $activity_id  Activity ID
 */
function gamipress_peepso_common_activity_listener( $post_id, $activity_id ) {

    $user_id = absint( get_post_field( 'post_author', $post_id ) );

    // Trigger events depending of current filter since is a common listener
    switch( current_filter() ) {
        case 'peepso_activity_after_add_post':
            do_action( 'gamipress_peepso_new_activity_post', $activity_id, $user_id, $post_id );
            break;
        case 'peepso_activity_after_add_comment':
            do_action( 'gamipress_peepso_new_activity_comment', $activity_id, $user_id, $post_id );
            break;
    }

}
do_action( 'peepso_activity_after_add_post', 'gamipress_peepso_common_activity_listener', 10, 2 );
do_action( 'peepso_activity_after_add_comment', 'gamipress_peepso_common_activity_listener', 10, 2 );

/**
 * Common friendship events listener
 *
 * @since 1.0.0
 *
 * @param int $from_user_id Form user ID
 * @param int $to_user_id   To user ID
 */
function gamipress_peepso_common_friends_listener( $from_user_id, $to_user_id ) {

    // Trigger events depending of current filter since is a common listener
    switch( current_filter() ) {
        case 'peepso_friends_requests_after_add':
            do_action( 'gamipress_peepso_friend_request', $from_user_id, $to_user_id );
            break;
        case 'peepso_friends_requests_after_accept':
            do_action( 'gamipress_peepso_friend_add', $from_user_id, $to_user_id );
            break;
    }

}
do_action( 'peepso_friends_requests_after_add', 'gamipress_peepso_common_friends_listener', 10, 2 );
do_action( 'peepso_friends_requests_after_accept', 'gamipress_peepso_common_friends_listener', 10, 2 );

/**
 * Create a group listener
 *
 * @since 1.0.0
 *
 * @param PeepSoGroup $group The group object
 */
function gamipress_peepso_create_group( $group ) {

    do_action( 'gamipress_peepso_create_group', $group->id, $group->owner_id );

}
do_action( 'peepso_action_group_create', 'gamipress_peepso_create_group', 10 );

/**
 * Join a group listener
 *
 * @since 1.0.0
 *
 * @param int $group_id The group ID
 * @param int $user_id  The user ID
 */
function gamipress_peepso_join_group( $group_id, $user_id ) {

    // Trigger join a group
    do_action( 'gamipress_peepso_join_group', $group_id, $user_id );

    // Trigger join a specific group
    do_action( 'gamipress_peepso_join_specific_group', $group_id, $user_id );

}
do_action( 'peepso_action_group_user_join', 'gamipress_peepso_join_group', 10, 2 );

/**
 * Common groups events listener
 *
 * @since 1.0.0
 *
 * @param int $group_id The group ID
 */
function gamipress_peepso_common_groups_listener( $group_id ) {

    $user_id = get_current_user_id();

    // Trigger events depending of current filter since is a common listener
    switch( current_filter() ) {
        case 'peepso_groups_after_change_avatar':
            do_action( 'gamipress_peepso_change_group_avatar', $group_id, $user_id );
            break;
        case 'peepso_groups_after_change_cover':
            do_action( 'gamipress_peepso_change_group_cover', $group_id, $user_id );
            break;
    }

}
do_action( 'peepso_groups_after_change_avatar', 'gamipress_peepso_common_groups_listener', 10 );
do_action( 'peepso_groups_after_change_cover', 'gamipress_peepso_common_groups_listener', 10 );

/**
 * Send a message listener
 *
 * @since 1.0.0
 *
 * @param int $message_id The message ID
 */
function gamipress_peepso_new_conversation( $message_id ) {

    $user_id = absint( get_post_field( 'post_author', $message_id ) );

    do_action( 'gamipress_peepso_new_conversation', $message_id, $user_id );

}
do_action( 'peepso_messages_new_conversation', 'gamipress_peepso_new_conversation', 10 );