<?php
/**
 * Triggers
 *
 * @package GamiPress\PeepSo\Triggers
 * @since 1.0.0
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Register plugin specific triggers
 *
 * @since  1.0.0
 *
 * @param array $triggers
 * @return mixed
 */
function gamipress_peepso_activity_triggers( $triggers ) {

    $triggers[__( 'PeepSo', 'gamipress-peepso-integration' )] = array(
        'gamipress_peepso_change_avatar'        => __( 'Change profile avatar', 'gamipress-peepso-integration' ),
        'gamipress_peepso_change_cover'         => __( 'Change cover image', 'gamipress-peepso-integration' ),
        'gamipress_peepso_new_activity_post'    => __( 'Write an activity post', 'gamipress-peepso-integration' ),
        'gamipress_peepso_new_activity_comment' => __( 'Write a comment on an activity post', 'gamipress-peepso-integration' ),
    );

    // Friends
    if( class_exists( 'PeepSoFriendsPlugin' ) ) {
        $triggers[__( 'PeepSo Friends', 'gamipress-peepso-integration' )] = array(
            'gamipress_peepso_friend_request'   => __( 'Send a friend request', 'gamipress-peepso-integration' ),
            'gamipress_peepso_friend_add'       => __( 'Add a new friend', 'gamipress-peepso-integration' ),
        );
    }

    // Groups
    if( class_exists( 'PeepSoGroupsPlugin' ) ) {
        $triggers[__( 'PeepSo Groups', 'gamipress-peepso-integration' )] = array(
            'gamipress_peepso_create_group'         => __( 'Create a group', 'gamipress-peepso-integration' ),
            'gamipress_peepso_join_group'           => __( 'Join a group', 'gamipress-peepso-integration' ),
            'gamipress_peepso_join_specific_group'  => __( 'Join a specific group', 'gamipress-peepso-integration' ),
            'gamipress_peepso_change_group_avatar'  => __( 'Change group avatar', 'gamipress-peepso-integration' ),
            'gamipress_peepso_change_group_cover'   => __( 'Change group cover image', 'gamipress-peepso-integration' ),
        );
    }

    // Messages
    if( class_exists( 'PeepSoMessagesPlugin' ) ) {
        $triggers[__( 'PeepSo Messages', 'gamipress-peepso-integration' )] = array(
            'gamipress_peepso_new_conversation' => __( 'Send a message', 'gamipress-peepso-integration' ),
        );
    }

    return $triggers;

}
add_filter( 'gamipress_activity_triggers', 'gamipress_peepso_activity_triggers' );

/**
 * Register plugin specific activity triggers
 *
 * @since  1.0.0
 *
 * @param  array $specific_activity_triggers
 * @return array
 */
function gamipress_peepso_specific_activity_triggers( $specific_activity_triggers ) {

    // Groups
    if( class_exists( 'PeepSoGroupsPlugin' ) ) {
        $specific_activity_triggers['gamipress_peepso_join_specific_group'] = array( PeepSoGroup::POST_TYPE );
    }

    return $specific_activity_triggers;
}
add_filter( 'gamipress_specific_activity_triggers', 'gamipress_peepso_specific_activity_triggers' );

/**
 * Register plugin specific activity triggers labels
 *
 * @since  1.0.0
 *
 * @param  array $specific_activity_trigger_labels
 * @return array
 */
function gamipress_peepso_specific_activity_trigger_label( $specific_activity_trigger_labels ) {

    $specific_activity_trigger_labels['gamipress_peepso_join_specific_group'] = __( 'Join %s group', 'gamipress-peepso-integration' );

    return $specific_activity_trigger_labels;
}
add_filter( 'gamipress_specific_activity_trigger_label', 'gamipress_peepso_specific_activity_trigger_label' );

/**
 * Get user for a PeepSo trigger action.
 *
 * @since  1.0.0
 *
 * @param  integer $user_id user ID to override.
 * @param  string  $trigger Trigger name.
 * @param  array   $args    Passed trigger args.
 * @return integer          User ID.
 */
function gamipress_peepso_trigger_get_user_id( $user_id, $trigger, $args ) {

    switch ( $trigger ) {
        case 'gamipress_peepso_change_avatar':
        case 'gamipress_peepso_change_cover':
        case 'gamipress_peepso_friend_request':
        case 'gamipress_peepso_friend_add':
            $user_id = $args[0];
            break;
        case 'gamipress_peepso_new_activity_post':
        case 'gamipress_peepso_new_activity_comment':
        case 'gamipress_peepso_create_group':
        case 'gamipress_peepso_join_group':
        case 'gamipress_peepso_join_specific_group':
        case 'gamipress_peepso_change_group_avatar':
        case 'gamipress_peepso_change_group_cover':
            $user_id = $args[1];
            break;
    }

    return $user_id;

}
add_filter( 'gamipress_trigger_get_user_id', 'gamipress_peepso_trigger_get_user_id', 10, 3 );

/**
 * Get the id for a PeepSo specific trigger action.
 *
 * @since  1.0.0
 *
 * @param  integer  $specific_id Specific ID.
 * @param  string  $trigger Trigger name.
 * @param  array   $args    Passed trigger args.
 *
 * @return integer          Specific ID.
 */
function gamipress_peepso_specific_trigger_get_id( $specific_id, $trigger = '', $args = array() ) {

    switch ( $trigger ) {
        case 'gamipress_peepso_join_specific_group':
            $specific_id = $args[0];
            break;
    }

    return $specific_id;
}
add_filter( 'gamipress_specific_trigger_get_id', 'gamipress_peepso_specific_trigger_get_id', 10, 3 );

/**
 * Extended meta data for event trigger logging
 *
 * @since 1.0.0
 *
 * @param array 	$log_meta
 * @param integer 	$user_id
 * @param string 	$trigger
 * @param integer 	$site_id
 * @param array 	$args
 *
 * @return array
 */
function gamipress_peepso_log_event_trigger_meta_data( $log_meta, $user_id, $trigger, $site_id, $args ) {

    switch ( $trigger ) {
        case 'gamipress_peepso_new_activity_post':
        case 'gamipress_peepso_new_activity_comment':
            // Add the activity and post IDs
            $log_meta['activity_id'] = $args[0];
            $log_meta['post_id'] = $args[2];
            break;
        case 'gamipress_peepso_friend_request':
        case 'gamipress_peepso_friend_add':
            // Add the friend ID
            $log_meta['friend_id'] = $args[1];
            break;
        case 'gamipress_peepso_create_group':
        case 'gamipress_peepso_join_group':
        case 'gamipress_peepso_join_specific_group':
        case 'gamipress_peepso_change_group_avatar':
        case 'gamipress_peepso_change_group_cover':
            // Add the group ID
            $log_meta['group_id'] = $args[0];
            break;
    }

    return $log_meta;
}
add_filter( 'gamipress_log_event_trigger_meta_data', 'gamipress_peepso_log_event_trigger_meta_data', 10, 5 );